;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "typst-preview" "20251110.824"
  "Live preview of typst."
  '((emacs     "28.1")
    (websocket "1.15")
    (compat    "30.1"))
  :url "https://github.com/havarddj/typst-preview.el"
  :commit "c685857f2d61133fc268509b39796b2718728f29"
  :revdesc "c685857f2d61"
  :keywords '("convenience" "languages" "tools")
  :authors '(("Håvard Damm-Johnsen" . "havard-dj@proton.me"))
  :maintainers '(("Håvard Damm-Johnsen" . "havard-dj@proton.me")))
